﻿using Syncfusion.UI.Xaml.Charts;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Threading;

namespace RealtimeUpdate
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private DispatcherTimer timer;
        private ViewModel viewModel;
        private ObservableCollection<DataValues> dataValue;
        public MainWindow()
        {
            InitializeComponent();
            viewModel = new ViewModel();
        }

        void timer_Tick(object sender, EventArgs e)
        {
            var lastData = dataValue[dataValue.Count - 1];
            var date = lastData.Year;
            var value = lastData.Count;
            var random = new Random();

            for (int i = 0; i < 10000; i++)
            {
                date.AddHours(1);
                if (random.NextDouble() > .5)
                {
                    value += random.NextDouble();
                }
                else
                {
                    value -= random.NextDouble();
                }
                dataValue.Add(new DataValues(date, value));
            }

        }

        private void LoadData(object sender, RoutedEventArgs e)
        {
            dataValue = viewModel.GenerateData();
            Chart.Series[0].ItemsSource = dataValue;     
        }

        private void StartUpdate(object sender, RoutedEventArgs e)
        {
            timer = new DispatcherTimer();
            timer.Interval = new TimeSpan(0, 0, 0, 0, 20);
            timer.Tick += timer_Tick;
            timer.Start();
        }

        private void StopUpdate(object sender, RoutedEventArgs e)
        {
            timer.Stop();
        }

        private void CategoryAxis_ActualRangeChanged(object sender, ActualRangeChangedEventArgs e)
        {
            //Comment the below line of code to stop auto scrolling
            //e.VisibleMaximum = (double)e.ActualMaximum + 10000d;
            //e.VisibleMinimum = ((double)e.ActualMaximum - 1000000) + 10000d;
        }
    }

    public class ViewModel
    {
        private Random random;

         public ViewModel()
        {
            random = new Random();
        }

        public ObservableCollection<DataValues> GenerateData()
        {
            ObservableCollection<DataValues> datas = new ObservableCollection<DataValues>();
            double value = 1000;
            DateTime date = new DateTime(2012, 1, 1);
            
            for (int i = 0; i < 1000000; i++)
            {
                datas.Add(new DataValues(date,value));
                date = date.Add(TimeSpan.FromMinutes(5));

                if (random.NextDouble() > .5)
                {
                    value += random.NextDouble();
                }
                else
                {
                    value -= random.NextDouble();
                }
            }
            return datas;
        }

      
    }

    public class DataValues
    {
        public DateTime Year { get; set; }

        public double Count { get; set; }

        public DataValues(DateTime year, double count)
        {
            Year = year;
            Count = count;
        }
    }
}
